==> wildfly-dist-10.1.0.Final-src.zip: wildfly-10.1.0.Final-src/testsuite/integration/clustering/src/test/java/org/jboss/as/test/clustering/cluster/ExtendedClusterAbstractTestCase.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.clustering.cluster;

import org.jboss.as.test.clustering.ExtendedClusteringTestConstants;

/**
 * Base cluster test that ensures the custom containers are already running.
 *
 * @author Richard Achmatowicz
 * @version May 2013
 */
public abstract class ExtendedClusterAbstractTestCase extends ClusterAbstractTestCase implements ExtendedClusteringTestConstants {

    @Override
    public void beforeTestMethod() {
        this.start(EXTENDED_CONTAINERS);
        this.deploy(EXTENDED_DEPLOYMENTS);
    }

    @Override
    public void afterTestMethod()
    {
        this.start(EXTENDED_CONTAINERS);
        this.undeploy(EXTENDED_DEPLOYMENTS);
    }
}

==> wildfly-dist-11.0.0.Final-src.zip: wildfly-11.0.0.Final-src/testsuite/integration/clustering/src/test/java/org/jboss/as/test/clustering/cluster/ExtendedClusterAbstractTestCase.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.clustering.cluster;

import org.jboss.as.test.clustering.ExtendedClusteringTestConstants;

/**
 * Base cluster test that ensures the custom containers are already running.
 *
 * @author Richard Achmatowicz
 * @version May 2013
 */
public abstract class ExtendedClusterAbstractTestCase extends ClusterAbstractTestCase implements ExtendedClusteringTestConstants {

    @Override
    public void beforeTestMethod() {
        this.start(EXTENDED_CONTAINERS);
        this.deploy(EXTENDED_DEPLOYMENTS);
    }

    @Override
    public void afterTestMethod() {
        this.start(EXTENDED_CONTAINERS);
        this.undeploy(EXTENDED_DEPLOYMENTS);
    }
}
